"""
The `domed` package contains functionality for directly manipulating the DOM structure in a pythonic way.
It is intended for use with Pyodide or Pyscript, for running Python in the browser.
The core module of the package contains generic functions and classes.
The modules `html` and `svg` define all the tags available for writing HTML and SVG. 
"""